@@ -6,10 +6,11 @@ Type annotations for backup-gateway service client.
 Usage::
 
     ```python
-    import boto3
-    from mypy_boto3_backup_gateway import BackupGatewayClient
+    from boto3.session import Session
+    from mypy_boto3_backup_gateway.client import BackupGatewayClient
 
-    client: BackupGatewayClient = boto3.client("backup-gateway")
+    session = Session()
+    client: BackupGatewayClient = session.client("backup-gateway")
     ```
 """
 import sys
@@ -65,7 +66,7 @@ class Exceptions:
 
 class BackupGatewayClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html)
     """
 
@@ -75,6 +76,9 @@ class BackupGatewayClient(BaseClient):
     def exceptions(self) -> Exceptions:
         """
         BackupGatewayClient exceptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#exceptions)
         """
 
     def associate_gateway_to_server(
@@ -83,7 +87,7 @@ class BackupGatewayClient(BaseClient):
         """
         Associates a backup gateway with your server.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client.associate_gateway_to_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.associate_gateway_to_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#associate_gateway_to_server)
         """
 
@@ -91,7 +95,7 @@ class BackupGatewayClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#can_paginate)
         """
 
@@ -106,7 +110,7 @@ class BackupGatewayClient(BaseClient):
         """
         Creates a backup gateway.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client.create_gateway)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.create_gateway)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#create_gateway)
         """
 
@@ -114,7 +118,7 @@ class BackupGatewayClient(BaseClient):
         """
         Deletes a backup gateway.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client.delete_gateway)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.delete_gateway)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#delete_gateway)
         """
 
@@ -122,7 +126,7 @@ class BackupGatewayClient(BaseClient):
         """
         Deletes a hypervisor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client.delete_hypervisor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.delete_hypervisor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#delete_hypervisor)
         """
 
@@ -132,7 +136,7 @@ class BackupGatewayClient(BaseClient):
         """
         Disassociates a backup gateway from the specified server.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client.disassociate_gateway_from_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.disassociate_gateway_from_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#disassociate_gateway_from_server)
         """
 
@@ -146,7 +150,7 @@ class BackupGatewayClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#generate_presigned_url)
         """
 
@@ -163,7 +167,7 @@ class BackupGatewayClient(BaseClient):
         """
         Connect to a hypervisor by importing its configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client.import_hypervisor_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.import_hypervisor_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#import_hypervisor_configuration)
         """
 
@@ -174,7 +178,7 @@ class BackupGatewayClient(BaseClient):
         Lists backup gateways owned by an Amazon Web Services account in an Amazon Web
         Services Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client.list_gateways)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.list_gateways)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#list_gateways)
         """
 
@@ -184,7 +188,7 @@ class BackupGatewayClient(BaseClient):
         """
         Lists your hypervisors.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client.list_hypervisors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.list_hypervisors)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#list_hypervisors)
         """
 
@@ -193,7 +197,7 @@ class BackupGatewayClient(BaseClient):
         Lists the tags applied to the resource identified by its Amazon Resource Name
         (ARN).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#list_tags_for_resource)
         """
 
@@ -203,7 +207,7 @@ class BackupGatewayClient(BaseClient):
         """
         Lists your virtual machines.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client.list_virtual_machines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.list_virtual_machines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#list_virtual_machines)
         """
 
@@ -219,7 +223,7 @@ class BackupGatewayClient(BaseClient):
         """
         Set the maintenance start time for a gateway.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client.put_maintenance_start_time)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.put_maintenance_start_time)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#put_maintenance_start_time)
         """
 
@@ -229,7 +233,7 @@ class BackupGatewayClient(BaseClient):
         """
         Tag the resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#tag_resource)
         """
 
@@ -240,7 +244,7 @@ class BackupGatewayClient(BaseClient):
         Tests your hypervisor configuration to validate that backup gateway can connect
         with the hypervisor and its resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client.test_hypervisor_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.test_hypervisor_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#test_hypervisor_configuration)
         """
 
@@ -250,7 +254,7 @@ class BackupGatewayClient(BaseClient):
         """
         Removes tags from the resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#untag_resource)
         """
 
@@ -260,7 +264,7 @@ class BackupGatewayClient(BaseClient):
         """
         Updates a gateway's name.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client.update_gateway_information)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.update_gateway_information)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#update_gateway_information)
         """
 
@@ -270,15 +274,15 @@ class BackupGatewayClient(BaseClient):
         """
         Updates a hypervisor metadata, including its host, username, and password.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Client.update_hypervisor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.update_hypervisor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#update_hypervisor)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_gateways"]) -> ListGatewaysPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Paginator.ListGateways)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/paginators.html#listgatewayspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#get_paginator)
         """
 
     @overload
@@ -286,8 +290,8 @@ class BackupGatewayClient(BaseClient):
         self, operation_name: Literal["list_hypervisors"]
     ) -> ListHypervisorsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Paginator.ListHypervisors)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/paginators.html#listhypervisorspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#get_paginator)
         """
 
     @overload
@@ -295,6 +299,6 @@ class BackupGatewayClient(BaseClient):
         self, operation_name: Literal["list_virtual_machines"]
     ) -> ListVirtualMachinesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/backup-gateway.html#BackupGateway.Paginator.ListVirtualMachines)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/paginators.html#listvirtualmachinespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup-gateway.html#BackupGateway.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup_gateway/client.html#get_paginator)
         """
